'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _echarts = require('echarts');

var _echarts2 = _interopRequireDefault(_echarts);

var _elementResizeEvent = require('element-resize-event');

var _elementResizeEvent2 = _interopRequireDefault(_elementResizeEvent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var ECharts = _react2.default.createClass({
    displayName: 'ECharts',

    propTypes: {
        style: _react2.default.PropTypes.object,
        theme: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.object]),
        group: _react2.default.PropTypes.string,
        option: _react2.default.PropTypes.object.isRequired,
        //是否不跟之前设置的option进行合并，默认为false，即合并
        notMerge: _react2.default.PropTypes.bool,
        //在设置完option后是否不立即刷新画布，默认为false，即立即刷新
        notRefreshImmediately: _react2.default.PropTypes.bool,
        onEvents: _react2.default.PropTypes.object
    },
    getDefaultProps: function getDefaultProps() {
        return {
            notMerge: false,
            notRefreshImmediately: false,
            onEvents: {},
            style: {},
            theme: {}
        };
    },
    componentDidMount: function componentDidMount() {
        this.init();
    },
    componentDidUpdate: function componentDidUpdate() {
        this.renderEcharts();
    },
    componentWillUnmount: function componentWillUnmount() {
        this.dispose();
    },
    init: function init() {
        this.chart = _echarts2.default.init(this.refs.container, this.props.theme);
        this.renderEcharts();
    },
    initEvents: function initEvents() {
        var _this = this;

        var onEvents = this.props.onEvents;
        for (var eventName in onEvents) {
            this.chart.on(eventName, onEvents[eventName]);
        }

        (0, _elementResizeEvent2.default)(this.refs.container, function () {
            _this.chart.resize();
        });
    },
    dispose: function dispose() {
        if (this.chart) {
            this.chart.dispose();
            this.chart = null;
        }
    },
    renderEcharts: function renderEcharts() {
        var _props = this.props;
        var option = _props.option;
        var notMerge = _props.notMerge;
        var notRefreshImmediately = _props.notRefreshImmediately;

        this.chart.showLoading();
        this.chart.setOption(option, notMerge, notRefreshImmediately);
        this.chart.hideLoading();
    },
    render: function render() {
        var _props2 = this.props;
        var id = _props2.id;
        var option = _props2.option;
        var style = _props2.style;
        var className = _props2.className;

        var props = _objectWithoutProperties(_props2, ['id', 'option', 'style', 'className']);

        var styles = Object.assign({
            width: '100%',
            height: '100%'
        }, style);

        return _react2.default.createElement('div', _extends({
            id: id,
            ref: 'container',
            style: styles
        }, props));
    }
});

var APIS = ['getMap', 'connect', 'disConnect', 'getInstanceByDom', 'registerMap', 'registerTheme'];
APIS.forEach(function (api) {
    ECharts[api] = _echarts2.default[api];
});

ECharts.dispatchAction = function (echartsId, payload) {
    var chartInstance = _echarts2.default.getInstanceByDom(document.getElementById(echartsId));
    return chartInstance.dispatchAction(payload);
};

exports.default = ECharts;